@@ -16,18 +16,33 @@ def loadJson(file: str):
         return data
 
 
+class FileCallback(BwApi.CallbackBase):
+    def Run(self, garment_id, callback_id, data_string):
+        try:
+            if callback_id == 1:
+                exportProduct()
+                return 1
+            else:
+                return 0
+
+        except Exception as e:
+            print(e)
+            BwApi.WndMessageBox(e, BwApi.BW_API_MB_OK)
+
+        return 1
+
+fileCallback = FileCallback()
+
+
 class EventCallback(BwApi.CallbackBase):
     exported = False
 
     def Run(self, garment_id, callback_id, data_string):
 
         try:
-            BwApi.WndMessageBox(str(callback_id), BwApi.BW_API_MB_OK)
             if callback_id == 0:
                 # TODO params + right actions
                 importFile()
-            if callback_id == 1:
-                exportProduct()
             if callback_id == 6:
                 if not self.exported:
                     self.exported = True
@@ -82,8 +97,9 @@ def exportFinish():
 # Main
 def BwApiPluginInit():
     BwApi.EventRegister(callback, 0, 0)
-    BwApi.EventRegister(callback, 1, 1)
     BwApi.EventRegister(callback, 6, 6)
 
+    BwApi.FileMethodRegister(fileCallback, 1, '.mdl', 'ext', 1)
+
     return int(0x000e0010)
 
